==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/app/translations/qmmp_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Ir para a próxima música na lista</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Ir para a música anterior na lista</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Começar a tocar a música atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Não limpar a lista de música</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausar a música atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausar se tocando, tocar se pausado</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Parar de tocar a música atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Exibir a janela Ir para Arquivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Saír do programa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Ajustar o volume do áudio (exemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation>Silenciar/Restaurar volume do áudio</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Exibir/Esconder aplicativo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Exibir a janela Adicionar Arquivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Exibir a janela Adicionar Pasta</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="306"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>qmmp [opção] [arquivo]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="307"/>
        <source>Options:</source>
        <translation>Opções:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="311"/>
        <source>Don&apos;t start the application</source>
        <translation>Não iniciar o aplicativo</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="313"/>
        <source>Print version number and exit</source>
        <translation>Exibir informações sobre a versão e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="314"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Enviar sugestões, correções e relatórios de erro para forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="317"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="330"/>
        <source>QMMP version: %1</source>
        <translation>Versão do Qmmp: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="331"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Versão do Qt usado para compilação: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="332"/>
        <source>Using Qt version: %1</source>
        <translation>Versão Qt usada: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="335"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="312"/>
        <source>Display this text and exit</source>
        <translation>Exibir esse texto e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="90"/>
        <source>Unknown command</source>
        <translation>Comando desconhecido</translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/app/translations/qmmp_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Não limpar a lista de música</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Começar a tocar a música atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausar a música atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausar se tocando, tocar se pausado</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Parar de tocar a música atual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Exibir a janela Ir para Arquivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Saír do programa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Ajustar o volume do áudio (exemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation>Silenciar/Restaurar volume do áudio</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Ir para a próxima música na lista</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Ir para a música anterior na lista</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Exibir/Esconder aplicativo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Mostrar janela principal</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Exibir a janela Adicionar Arquivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Exibir a janela Adicionar Pasta</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="93"/>
        <source>Unknown command</source>
        <translation>Comando desconhecido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="342"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>qmmp [opção] [arquivo]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="343"/>
        <source>Options:</source>
        <translation>Opções:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="347"/>
        <source>Don&apos;t start the application</source>
        <translation>Não iniciar o aplicativo</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="348"/>
        <source>Display this text and exit</source>
        <translation>Exibir esse texto e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="349"/>
        <source>Print version number and exit</source>
        <translation>Exibir informações sobre a versão e sair</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="350"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Enviar sugestões, correções e relatórios de erro para forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="353"/>
        <source>Command Line Help</source>
        <translation>Ajuda para linha de comandos</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="366"/>
        <source>QMMP version: %1</source>
        <translation>Versão do Qmmp: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="367"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Versão do Qt usado para compilação: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="368"/>
        <source>Using Qt version: %1</source>
        <translation>Versão Qt usada: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="371"/>
        <source>Qmmp Version</source>
        <translation>Versão Qmmp</translation>
    </message>
</context>
</TS>
